==> haskell-persistent-sqlite-2.6-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6
id: persistent-sqlite-2.6-6jkBZE6Ywiw6A413TURCpn
key: persistent-sqlite-2.6-6jkBZE6Ywiw6A413TURCpn
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 915135122093ef24a1e955e8f8db12f0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/persistent-sqlite-2.6
hs-libraries: HSpersistent-sqlite-2.6-6jkBZE6Ywiw6A413TURCpn
extra-libraries:
    pthread
depends:
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb
    containers-0.5.7.1 monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-32CBvhp6gFq5BE9pZkL20q
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    persistent-2.6-GvuThmb8AvVA76cBwelYX7
    resource-pool-0.2.3.2-E3OCiqwe137Er9aRv4slPP
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.6-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6
id: persistent-sqlite-2.6-2fIyxL1QMqbG9ps60ONkQH
key: persistent-sqlite-2.6-2fIyxL1QMqbG9ps60ONkQH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 2e15375b2c1d3074646d38008f1de040
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-sqlite-2.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/persistent-sqlite-2.6
hs-libraries: HSpersistent-sqlite-2.6-2fIyxL1QMqbG9ps60ONkQH
extra-libraries:
    pthread
depends:
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb
    containers-0.5.7.1 monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-32CBvhp6gFq5BE9pZkL20q
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    persistent-2.6-9fwweqtRRHr1qStNw5pXAk
    resource-pool-0.2.3.2-E3OCiqwe137Er9aRv4slPP
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
